==> prefab-cloud-java-0.0.1-sources.jar: cloud/prefab/domain/ConfigServiceGrpc.java <==
package cloud.prefab.domain;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.11.0)",
    comments = "Source: prefab.proto")
public final class ConfigServiceGrpc {

  private ConfigServiceGrpc() {}

  public static final String SERVICE_NAME = "prefab.ConfigService";

  // Static method descriptors that strictly reflect the proto.
  @io.grpc.ExperimentalApi("https://github.com/grpc/grpc-java/issues/1901")
  @java.lang.Deprecated // Use {@link #getGetConfigMethod()} instead. 
  public static final io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.ConfigServicePointer,
      cloud.prefab.domain.Prefab.ConfigDeltas> METHOD_GET_CONFIG = getGetConfigMethodHelper();

  private static volatile io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.ConfigServicePointer,
      cloud.prefab.domain.Prefab.ConfigDeltas> getGetConfigMethod;

  @io.grpc.ExperimentalApi("https://github.com/grpc/grpc-java/issues/1901")
  public static io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.ConfigServicePointer,
      cloud.prefab.domain.Prefab.ConfigDeltas> getGetConfigMethod() {
    return getGetConfigMethodHelper();
  }

  private static io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.ConfigServicePointer,
      cloud.prefab.domain.Prefab.ConfigDeltas> getGetConfigMethodHelper() {
    io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.ConfigServicePointer, cloud.prefab.domain.Prefab.ConfigDeltas> getGetConfigMethod;
    if ((getGetConfigMethod = ConfigServiceGrpc.getGetConfigMethod) == null) {
      synchronized (ConfigServiceGrpc.class) {
        if ((getGetConfigMethod = ConfigServiceGrpc.getGetConfigMethod) == null) {
          ConfigServiceGrpc.getGetConfigMethod = getGetConfigMethod = 
              io.grpc.MethodDescriptor.<cloud.prefab.domain.Prefab.ConfigServicePointer, cloud.prefab.domain.Prefab.ConfigDeltas>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
              .setFullMethodName(generateFullMethodName(
                  "prefab.ConfigService", "GetConfig"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.ConfigServicePointer.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.ConfigDeltas.getDefaultInstance()))
                  .setSchemaDescriptor(new ConfigServiceMethodDescriptorSupplier("GetConfig"))
                  .build();
          }
        }
     }
     return getGetConfigMethod;
  }
  @io.grpc.ExperimentalApi("https://github.com/grpc/grpc-java/issues/1901")
  @java.lang.Deprecated // Use {@link #getUpsertMethod()} instead. 
  public static final io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.UpsertRequest,
      cloud.prefab.domain.Prefab.ConfigServicePointer> METHOD_UPSERT = getUpsertMethodHelper();

  private static volatile io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.UpsertRequest,
      cloud.prefab.domain.Prefab.ConfigServicePointer> getUpsertMethod;

  @io.grpc.ExperimentalApi("https://github.com/grpc/grpc-java/issues/1901")
  public static io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.UpsertRequest,
      cloud.prefab.domain.Prefab.ConfigServicePointer> getUpsertMethod() {
    return getUpsertMethodHelper();
  }

  private static io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.UpsertRequest,
      cloud.prefab.domain.Prefab.ConfigServicePointer> getUpsertMethodHelper() {
    io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.UpsertRequest, cloud.prefab.domain.Prefab.ConfigServicePointer> getUpsertMethod;
    if ((getUpsertMethod = ConfigServiceGrpc.getUpsertMethod) == null) {
      synchronized (ConfigServiceGrpc.class) {
        if ((getUpsertMethod = ConfigServiceGrpc.getUpsertMethod) == null) {
          ConfigServiceGrpc.getUpsertMethod = getUpsertMethod = 
              io.grpc.MethodDescriptor.<cloud.prefab.domain.Prefab.UpsertRequest, cloud.prefab.domain.Prefab.ConfigServicePointer>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "prefab.ConfigService", "Upsert"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.UpsertRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.ConfigServicePointer.getDefaultInstance()))
                  .setSchemaDescriptor(new ConfigServiceMethodDescriptorSupplier("Upsert"))
                  .build();
          }
        }
     }
     return getUpsertMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static ConfigServiceStub newStub(io.grpc.Channel channel) {
    return new ConfigServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static ConfigServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new ConfigServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static ConfigServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new ConfigServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class ConfigServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void getConfig(cloud.prefab.domain.Prefab.ConfigServicePointer request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.ConfigDeltas> responseObserver) {
      asyncUnimplementedUnaryCall(getGetConfigMethodHelper(), responseObserver);
    }

    /**
     */
    public void upsert(cloud.prefab.domain.Prefab.UpsertRequest request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.ConfigServicePointer> responseObserver) {
      asyncUnimplementedUnaryCall(getUpsertMethodHelper(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getGetConfigMethodHelper(),
            asyncServerStreamingCall(
              new MethodHandlers<
                cloud.prefab.domain.Prefab.ConfigServicePointer,
                cloud.prefab.domain.Prefab.ConfigDeltas>(
                  this, METHODID_GET_CONFIG)))
          .addMethod(
            getUpsertMethodHelper(),
            asyncUnaryCall(
              new MethodHandlers<
                cloud.prefab.domain.Prefab.UpsertRequest,
                cloud.prefab.domain.Prefab.ConfigServicePointer>(
                  this, METHODID_UPSERT)))
          .build();
    }
  }

  /**
   */
  public static final class ConfigServiceStub extends io.grpc.stub.AbstractStub<ConfigServiceStub> {
    private ConfigServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private ConfigServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ConfigServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new ConfigServiceStub(channel, callOptions);
    }

    /**
     */
    public void getConfig(cloud.prefab.domain.Prefab.ConfigServicePointer request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.ConfigDeltas> responseObserver) {
      asyncServerStreamingCall(
          getChannel().newCall(getGetConfigMethodHelper(), getCallOptions()), request, responseObserver);
    }

    /**
     */
    public void upsert(cloud.prefab.domain.Prefab.UpsertRequest request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.ConfigServicePointer> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getUpsertMethodHelper(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class ConfigServiceBlockingStub extends io.grpc.stub.AbstractStub<ConfigServiceBlockingStub> {
    private ConfigServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private ConfigServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ConfigServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new ConfigServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public java.util.Iterator<cloud.prefab.domain.Prefab.ConfigDeltas> getConfig(
        cloud.prefab.domain.Prefab.ConfigServicePointer request) {
      return blockingServerStreamingCall(
          getChannel(), getGetConfigMethodHelper(), getCallOptions(), request);
    }

    /**
     */
    public cloud.prefab.domain.Prefab.ConfigServicePointer upsert(cloud.prefab.domain.Prefab.UpsertRequest request) {
      return blockingUnaryCall(
          getChannel(), getUpsertMethodHelper(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class ConfigServiceFutureStub extends io.grpc.stub.AbstractStub<ConfigServiceFutureStub> {
    private ConfigServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private ConfigServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ConfigServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new ConfigServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<cloud.prefab.domain.Prefab.ConfigServicePointer> upsert(
        cloud.prefab.domain.Prefab.UpsertRequest request) {
      return futureUnaryCall(
          getChannel().newCall(getUpsertMethodHelper(), getCallOptions()), request);
    }
  }

  private static final int METHODID_GET_CONFIG = 0;
  private static final int METHODID_UPSERT = 1;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final ConfigServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(ConfigServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GET_CONFIG:
          serviceImpl.getConfig((cloud.prefab.domain.Prefab.ConfigServicePointer) request,
              (io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.ConfigDeltas>) responseObserver);
          break;
        case METHODID_UPSERT:
          serviceImpl.upsert((cloud.prefab.domain.Prefab.UpsertRequest) request,
              (io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.ConfigServicePointer>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class ConfigServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    ConfigServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return cloud.prefab.domain.Prefab.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("ConfigService");
    }
  }

  private static final class ConfigServiceFileDescriptorSupplier
      extends ConfigServiceBaseDescriptorSupplier {
    ConfigServiceFileDescriptorSupplier() {}
  }

  private static final class ConfigServiceMethodDescriptorSupplier
      extends ConfigServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    ConfigServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (ConfigServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new ConfigServiceFileDescriptorSupplier())
              .addMethod(getGetConfigMethodHelper())
              .addMethod(getUpsertMethodHelper())
              .build();
        }
      }
    }
    return result;
  }
}

==> prefab-cloud-java-0.0.7-sources.jar: cloud/prefab/domain/ConfigServiceGrpc.java <==
package cloud.prefab.domain;

import static io.grpc.MethodDescriptor.generateFullMethodName;
import static io.grpc.stub.ClientCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ClientCalls.asyncClientStreamingCall;
import static io.grpc.stub.ClientCalls.asyncServerStreamingCall;
import static io.grpc.stub.ClientCalls.asyncUnaryCall;
import static io.grpc.stub.ClientCalls.blockingServerStreamingCall;
import static io.grpc.stub.ClientCalls.blockingUnaryCall;
import static io.grpc.stub.ClientCalls.futureUnaryCall;
import static io.grpc.stub.ServerCalls.asyncBidiStreamingCall;
import static io.grpc.stub.ServerCalls.asyncClientStreamingCall;
import static io.grpc.stub.ServerCalls.asyncServerStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnaryCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedStreamingCall;
import static io.grpc.stub.ServerCalls.asyncUnimplementedUnaryCall;

/**
 */
@javax.annotation.Generated(
    value = "by gRPC proto compiler (version 1.15.0)",
    comments = "Source: prefab.proto")
public final class ConfigServiceGrpc {

  private ConfigServiceGrpc() {}

  public static final String SERVICE_NAME = "prefab.ConfigService";

  // Static method descriptors that strictly reflect the proto.
  private static volatile io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.ConfigServicePointer,
      cloud.prefab.domain.Prefab.ConfigDeltas> getGetConfigMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "GetConfig",
      requestType = cloud.prefab.domain.Prefab.ConfigServicePointer.class,
      responseType = cloud.prefab.domain.Prefab.ConfigDeltas.class,
      methodType = io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
  public static io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.ConfigServicePointer,
      cloud.prefab.domain.Prefab.ConfigDeltas> getGetConfigMethod() {
    io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.ConfigServicePointer, cloud.prefab.domain.Prefab.ConfigDeltas> getGetConfigMethod;
    if ((getGetConfigMethod = ConfigServiceGrpc.getGetConfigMethod) == null) {
      synchronized (ConfigServiceGrpc.class) {
        if ((getGetConfigMethod = ConfigServiceGrpc.getGetConfigMethod) == null) {
          ConfigServiceGrpc.getGetConfigMethod = getGetConfigMethod = 
              io.grpc.MethodDescriptor.<cloud.prefab.domain.Prefab.ConfigServicePointer, cloud.prefab.domain.Prefab.ConfigDeltas>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.SERVER_STREAMING)
              .setFullMethodName(generateFullMethodName(
                  "prefab.ConfigService", "GetConfig"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.ConfigServicePointer.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.ConfigDeltas.getDefaultInstance()))
                  .setSchemaDescriptor(new ConfigServiceMethodDescriptorSupplier("GetConfig"))
                  .build();
          }
        }
     }
     return getGetConfigMethod;
  }

  private static volatile io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.UpsertRequest,
      cloud.prefab.domain.Prefab.ConfigServicePointer> getUpsertMethod;

  @io.grpc.stub.annotations.RpcMethod(
      fullMethodName = SERVICE_NAME + '/' + "Upsert",
      requestType = cloud.prefab.domain.Prefab.UpsertRequest.class,
      responseType = cloud.prefab.domain.Prefab.ConfigServicePointer.class,
      methodType = io.grpc.MethodDescriptor.MethodType.UNARY)
  public static io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.UpsertRequest,
      cloud.prefab.domain.Prefab.ConfigServicePointer> getUpsertMethod() {
    io.grpc.MethodDescriptor<cloud.prefab.domain.Prefab.UpsertRequest, cloud.prefab.domain.Prefab.ConfigServicePointer> getUpsertMethod;
    if ((getUpsertMethod = ConfigServiceGrpc.getUpsertMethod) == null) {
      synchronized (ConfigServiceGrpc.class) {
        if ((getUpsertMethod = ConfigServiceGrpc.getUpsertMethod) == null) {
          ConfigServiceGrpc.getUpsertMethod = getUpsertMethod = 
              io.grpc.MethodDescriptor.<cloud.prefab.domain.Prefab.UpsertRequest, cloud.prefab.domain.Prefab.ConfigServicePointer>newBuilder()
              .setType(io.grpc.MethodDescriptor.MethodType.UNARY)
              .setFullMethodName(generateFullMethodName(
                  "prefab.ConfigService", "Upsert"))
              .setSampledToLocalTracing(true)
              .setRequestMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.UpsertRequest.getDefaultInstance()))
              .setResponseMarshaller(io.grpc.protobuf.ProtoUtils.marshaller(
                  cloud.prefab.domain.Prefab.ConfigServicePointer.getDefaultInstance()))
                  .setSchemaDescriptor(new ConfigServiceMethodDescriptorSupplier("Upsert"))
                  .build();
          }
        }
     }
     return getUpsertMethod;
  }

  /**
   * Creates a new async stub that supports all call types for the service
   */
  public static ConfigServiceStub newStub(io.grpc.Channel channel) {
    return new ConfigServiceStub(channel);
  }

  /**
   * Creates a new blocking-style stub that supports unary and streaming output calls on the service
   */
  public static ConfigServiceBlockingStub newBlockingStub(
      io.grpc.Channel channel) {
    return new ConfigServiceBlockingStub(channel);
  }

  /**
   * Creates a new ListenableFuture-style stub that supports unary calls on the service
   */
  public static ConfigServiceFutureStub newFutureStub(
      io.grpc.Channel channel) {
    return new ConfigServiceFutureStub(channel);
  }

  /**
   */
  public static abstract class ConfigServiceImplBase implements io.grpc.BindableService {

    /**
     */
    public void getConfig(cloud.prefab.domain.Prefab.ConfigServicePointer request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.ConfigDeltas> responseObserver) {
      asyncUnimplementedUnaryCall(getGetConfigMethod(), responseObserver);
    }

    /**
     */
    public void upsert(cloud.prefab.domain.Prefab.UpsertRequest request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.ConfigServicePointer> responseObserver) {
      asyncUnimplementedUnaryCall(getUpsertMethod(), responseObserver);
    }

    @java.lang.Override public final io.grpc.ServerServiceDefinition bindService() {
      return io.grpc.ServerServiceDefinition.builder(getServiceDescriptor())
          .addMethod(
            getGetConfigMethod(),
            asyncServerStreamingCall(
              new MethodHandlers<
                cloud.prefab.domain.Prefab.ConfigServicePointer,
                cloud.prefab.domain.Prefab.ConfigDeltas>(
                  this, METHODID_GET_CONFIG)))
          .addMethod(
            getUpsertMethod(),
            asyncUnaryCall(
              new MethodHandlers<
                cloud.prefab.domain.Prefab.UpsertRequest,
                cloud.prefab.domain.Prefab.ConfigServicePointer>(
                  this, METHODID_UPSERT)))
          .build();
    }
  }

  /**
   */
  public static final class ConfigServiceStub extends io.grpc.stub.AbstractStub<ConfigServiceStub> {
    private ConfigServiceStub(io.grpc.Channel channel) {
      super(channel);
    }

    private ConfigServiceStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ConfigServiceStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new ConfigServiceStub(channel, callOptions);
    }

    /**
     */
    public void getConfig(cloud.prefab.domain.Prefab.ConfigServicePointer request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.ConfigDeltas> responseObserver) {
      asyncServerStreamingCall(
          getChannel().newCall(getGetConfigMethod(), getCallOptions()), request, responseObserver);
    }

    /**
     */
    public void upsert(cloud.prefab.domain.Prefab.UpsertRequest request,
        io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.ConfigServicePointer> responseObserver) {
      asyncUnaryCall(
          getChannel().newCall(getUpsertMethod(), getCallOptions()), request, responseObserver);
    }
  }

  /**
   */
  public static final class ConfigServiceBlockingStub extends io.grpc.stub.AbstractStub<ConfigServiceBlockingStub> {
    private ConfigServiceBlockingStub(io.grpc.Channel channel) {
      super(channel);
    }

    private ConfigServiceBlockingStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ConfigServiceBlockingStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new ConfigServiceBlockingStub(channel, callOptions);
    }

    /**
     */
    public java.util.Iterator<cloud.prefab.domain.Prefab.ConfigDeltas> getConfig(
        cloud.prefab.domain.Prefab.ConfigServicePointer request) {
      return blockingServerStreamingCall(
          getChannel(), getGetConfigMethod(), getCallOptions(), request);
    }

    /**
     */
    public cloud.prefab.domain.Prefab.ConfigServicePointer upsert(cloud.prefab.domain.Prefab.UpsertRequest request) {
      return blockingUnaryCall(
          getChannel(), getUpsertMethod(), getCallOptions(), request);
    }
  }

  /**
   */
  public static final class ConfigServiceFutureStub extends io.grpc.stub.AbstractStub<ConfigServiceFutureStub> {
    private ConfigServiceFutureStub(io.grpc.Channel channel) {
      super(channel);
    }

    private ConfigServiceFutureStub(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      super(channel, callOptions);
    }

    @java.lang.Override
    protected ConfigServiceFutureStub build(io.grpc.Channel channel,
        io.grpc.CallOptions callOptions) {
      return new ConfigServiceFutureStub(channel, callOptions);
    }

    /**
     */
    public com.google.common.util.concurrent.ListenableFuture<cloud.prefab.domain.Prefab.ConfigServicePointer> upsert(
        cloud.prefab.domain.Prefab.UpsertRequest request) {
      return futureUnaryCall(
          getChannel().newCall(getUpsertMethod(), getCallOptions()), request);
    }
  }

  private static final int METHODID_GET_CONFIG = 0;
  private static final int METHODID_UPSERT = 1;

  private static final class MethodHandlers<Req, Resp> implements
      io.grpc.stub.ServerCalls.UnaryMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ServerStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.ClientStreamingMethod<Req, Resp>,
      io.grpc.stub.ServerCalls.BidiStreamingMethod<Req, Resp> {
    private final ConfigServiceImplBase serviceImpl;
    private final int methodId;

    MethodHandlers(ConfigServiceImplBase serviceImpl, int methodId) {
      this.serviceImpl = serviceImpl;
      this.methodId = methodId;
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public void invoke(Req request, io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        case METHODID_GET_CONFIG:
          serviceImpl.getConfig((cloud.prefab.domain.Prefab.ConfigServicePointer) request,
              (io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.ConfigDeltas>) responseObserver);
          break;
        case METHODID_UPSERT:
          serviceImpl.upsert((cloud.prefab.domain.Prefab.UpsertRequest) request,
              (io.grpc.stub.StreamObserver<cloud.prefab.domain.Prefab.ConfigServicePointer>) responseObserver);
          break;
        default:
          throw new AssertionError();
      }
    }

    @java.lang.Override
    @java.lang.SuppressWarnings("unchecked")
    public io.grpc.stub.StreamObserver<Req> invoke(
        io.grpc.stub.StreamObserver<Resp> responseObserver) {
      switch (methodId) {
        default:
          throw new AssertionError();
      }
    }
  }

  private static abstract class ConfigServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoFileDescriptorSupplier, io.grpc.protobuf.ProtoServiceDescriptorSupplier {
    ConfigServiceBaseDescriptorSupplier() {}

    @java.lang.Override
    public com.google.protobuf.Descriptors.FileDescriptor getFileDescriptor() {
      return cloud.prefab.domain.Prefab.getDescriptor();
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.ServiceDescriptor getServiceDescriptor() {
      return getFileDescriptor().findServiceByName("ConfigService");
    }
  }

  private static final class ConfigServiceFileDescriptorSupplier
      extends ConfigServiceBaseDescriptorSupplier {
    ConfigServiceFileDescriptorSupplier() {}
  }

  private static final class ConfigServiceMethodDescriptorSupplier
      extends ConfigServiceBaseDescriptorSupplier
      implements io.grpc.protobuf.ProtoMethodDescriptorSupplier {
    private final String methodName;

    ConfigServiceMethodDescriptorSupplier(String methodName) {
      this.methodName = methodName;
    }

    @java.lang.Override
    public com.google.protobuf.Descriptors.MethodDescriptor getMethodDescriptor() {
      return getServiceDescriptor().findMethodByName(methodName);
    }
  }

  private static volatile io.grpc.ServiceDescriptor serviceDescriptor;

  public static io.grpc.ServiceDescriptor getServiceDescriptor() {
    io.grpc.ServiceDescriptor result = serviceDescriptor;
    if (result == null) {
      synchronized (ConfigServiceGrpc.class) {
        result = serviceDescriptor;
        if (result == null) {
          serviceDescriptor = result = io.grpc.ServiceDescriptor.newBuilder(SERVICE_NAME)
              .setSchemaDescriptor(new ConfigServiceFileDescriptorSupplier())
              .addMethod(getGetConfigMethod())
              .addMethod(getUpsertMethod())
              .build();
        }
      }
    }
    return result;
  }
}
